@@ -10,6 +10,8 @@ use Carp ();
 my $ACHAR = $URI::uric;  $ACHAR =~ s,\\[/?],,g;
 my $PCHAR = $URI::uric;  $PCHAR =~ s,\\[?],,g;
 
+sub _no_scheme_ok { 1 }
+
 sub authority
 {
     my $self = shift;
@@ -119,7 +121,7 @@ sub _split_segment
 sub abs
 {
     my $self = shift;
-    my $base = shift || die "Missing base argument";
+    my $base = shift || Carp::croak("Missing base argument");
 
     if (my $scheme = $self->scheme) {
 	return $self unless $URI::ABS_ALLOW_RELATIVE_SCHEME;
@@ -171,10 +173,10 @@ sub abs
     $abs;
 }
 
-# The oposite of $url->abs.  Return a URI which is much relative as possible
+# The oposite of $url->abs.  Return a URI which is as relative as possible
 sub rel {
     my $self = shift;
-    my $base = shift || die "Missing base argument";
+    my $base = shift || Carp::croak("Missing base argument");
     my $rel = $self->clone;
     $base = URI->new($base) unless ref $base;
 
